/* See LICENSE file for copyright and license details. */
#include <X11/XF86keysym.h>

/* appearance */
static const unsigned int borderpx  = 1;        /* border pixel of windows */
static const unsigned int snap      = 32;       /* snap pixel */
static const unsigned int systraypinning = 0;   /* 0: sloppy systray follows selected monitor, >0: pin systray to monitor X */
static const unsigned int systrayspacing = 2;   /* systray spacing */
static const int systraypinningfailfirst = 1;   /* 1: if pinning fails, display systray on the first monitor, False: display systray on the last monitor*/
static const int showsystray        = 1;     /* 0 means no systray */
static const int showbar            = 1;        /* 0 means no bar */
static const int topbar             = 1;        /* 0 means bottom bar */
static const char *fonts[]          = {
	"Hack:style=Bold:size=10",
	"DejaVuSans:style=Bold:size=12",			/* For the symbols */
};
static const char dmenufont[]       = "Hack:style=Bold:size=10";
static const char col_dark[]        = "#282828";
static const char col_gray[]        = "#928374";
static const char col_gray1[]       = "#3c3836";
static const char col_gray2[]       = "#504945";
static const char col_gray3[]       = "#7c6f64";
static const char col_clear[]       = "#ebdbd2";
static const char col_orange[]      = "#fe8019";
static const char col_dark_orange[] = "#d65d0e";
static const char col_invalid[]     = "#ff00ff";
static const char *colors[][3]      = {
	/*               fg         bg          border   */
	[SchemeNorm] = { col_gray,  col_dark,   col_dark },
	[SchemeSel] =  { col_gray1, col_orange, col_gray2  },
	[SchemeSystray] = { col_invalid, col_orange, col_invalid },
};

/* tagging */
static const char *tags[] = { "1", "2", "3", "4", "5", "6", "7", "8", "9" };

static const Rule rules[] = {
	/* xprop(1):
	 *	WM_CLASS(STRING) = instance, class
	 *	WM_NAME(STRING) = title
	 */
	/* class      instance    title       tags mask     isfloating   monitor */
	{ "mpv",      NULL,       NULL,       0,            1,           -1 },
	{ "Firefox",  NULL,       NULL,       0,            0,           -1 },
	{ "KeePass2", NULL,       NULL,       1<<8,         0,           -1 },
	/* Add the " - " at the start to match only the main window */
	{ " - KeePassXC",NULL,       NULL,       1<<8,         0,           -1 },
};

/* layout(s) */
static const float mfact     = 0.55; /* factor of master area size [0.05..0.95] */
static const int nmaster     = 1;    /* number of clients in master area */
static const int resizehints = 1;    /* 1 means respect size hints in tiled resizals */

static const Layout layouts[] = {
	/* symbol     arrange function */
	{ "[]=",      tile },    /* first entry is default */
	{ "><>",      NULL },    /* no layout function means floating behavior */
	{ "[M]",      monocle },
};

/* key definitions */
#define MODKEY Mod1Mask
#define TAGKEYS(KEY,TAG) \
	{ MODKEY,                       KEY,      view,           {.ui = 1 << TAG} }, \
	{ MODKEY|ControlMask,           KEY,      toggleview,     {.ui = 1 << TAG} }, \
	{ MODKEY|ShiftMask,             KEY,      tag,            {.ui = 1 << TAG} }, \
	{ MODKEY|ControlMask|ShiftMask, KEY,      toggletag,      {.ui = 1 << TAG} },

/* helper for spawning shell commands in the pre dwm-5.0 fashion */
#define SHCMD(cmd) { .v = (const char*[]){ "/bin/sh", "-c", cmd, NULL } }

/* commands */
static char dmenumon[2] = "0"; /* component of dmenucmd, manipulated in spawn() */
static const char *dmenucmd[] = { "dmenu_run", "-m", dmenumon, "-fn", dmenufont, \
									"-nb", col_dark, "-nf", col_gray, \
									"-sb", col_orange, "-sf", col_gray1, NULL };
static const char *termcmd[]  = { "/usr/bin/kitty", "--single-instance", NULL };
static const char *backlightinccmd[]  = { "light", "-A", "5", NULL };
static const char *backlightdeccmd[]  = { "light", "-U", "5", NULL };
static const char *volup[]  = { "volcont", "--up", NULL };
static const char *voldown[]  = { "volcont", "--down", NULL };
static const char *voltog[]  = { "volcont", "--toggle", NULL };
static const char *slock[]  = { "slock", NULL };
static const char *touchtog[] = { "touchtog",  NULL }; /* touchpad toggle */
static const char *clipqr[] = { "cliplumber",  NULL }; /* clipboard to QR */
static const char *mpdtoggle[] = { "/usr/bin/mpc", "toggle", NULL };
static const char *mpdnext[] = { "/usr/bin/mpc", "next", NULL };
static const char *mpdprev[] = { "/usr/bin/mpc", "prev", NULL };
static const char *splatmoji[]  = { "/usr/bin/splatmoji", "type", NULL };

static Key keys[] = {
	/* modifier                     key            function        argument */
	{ 0,                XF86XK_MonBrightnessUp,    spawn,          {.v = backlightinccmd } },
	{ 0,                XF86XK_MonBrightnessDown,  spawn,          {.v = backlightdeccmd } },
	{ 0,                XF86XK_AudioRaiseVolume,   spawn,          {.v = volup } },
	{ 0,                XF86XK_AudioLowerVolume,   spawn,          {.v = voldown } },
	{ 0,                XF86XK_AudioMute,          spawn,          {.v = voltog } },
	{ 0,                XF86XK_TouchpadToggle,     spawn,          {.v = touchtog } },
	{ 0,                XF86XK_AudioPlay,          spawn,          {.v = mpdtoggle } },
	{ 0,                XF86XK_AudioPrev,          spawn,          {.v = mpdprev } },
	{ 0,                XF86XK_AudioNext,          spawn,          {.v = mpdnext } },
	//{ Mod4Mask,                     XK_Right,  spawn,              {.v = volup } },
	//{ Mod4Mask,                     XK_Left,   spawn,              {.v = voldown } },
	//{ Mod4Mask,                     XK_KP_0,   spawn,              {.v = voltog } },
	{ MODKEY,                       XK_r,          spawn,          {.v = dmenucmd } },
	{ MODKEY,                       XK_Return,     spawn,          {.v = termcmd } },
	{ MODKEY,                       XK_p,          spawn,          {.v = mpdtoggle } },
	{ MODKEY,                       XK_less,       spawn,          {.v = mpdprev } },
	{ MODKEY|ShiftMask,             XK_less,       spawn,          {.v = mpdnext } },
	{ MODKEY,                       XK_l,          spawn,          {.v = slock } },
	{ MODKEY,                       XK_v,          spawn,          {.v = clipqr } },
	//{ MODKEY,                       XK_e,          spawn,          {.v = splatmoji } },
	{ MODKEY,                       XK_b,          togglebar,      {0} },
	{ MODKEY,                       XK_Tab,        focusstack,     {.i = +1 } },
	{ MODKEY|ShiftMask,             XK_Tab,        focusstack,     {.i = -1 } },
	{ MODKEY|ShiftMask,             XK_Up,         incnmaster,     {.i = +1 } },
	{ MODKEY|ShiftMask,             XK_Down,       incnmaster,     {.i = -1 } },
	{ MODKEY,                       XK_Up,         setmfact,       {.f = -0.05} },
	{ MODKEY,                       XK_Down,       setmfact,       {.f = +0.05} },
	{ MODKEY|ShiftMask,             XK_Return,     zoom,           {0} },
	{ MODKEY,                       XK_j,          view,           {0} },
	{ MODKEY|ShiftMask,             XK_c,          killclient,     {0} },
	{ MODKEY,                       XK_t,          setlayout,      {.v = &layouts[0]} },
	{ MODKEY,                       XK_f,          setlayout,      {.v = &layouts[1]} },
	{ MODKEY,                       XK_m,          setlayout,      {.v = &layouts[2]} },
	{ MODKEY,                       XK_space,      setlayout,      {0} },
	{ MODKEY|ShiftMask,             XK_space,      togglefloating, {0} },
	/* Remove "show all tags" binding as it crashes X */
	// { MODKEY,                       XK_agrave,     view,           {.ui = ~0 } },
	// { MODKEY|ShiftMask,             XK_agrave,     tag,            {.ui = ~0 } },
	{ MODKEY,                       XK_comma,      focusmon,       {.i = -1 } },
	{ MODKEY,                       XK_semicolon,  focusmon,       {.i = +1 } },
	{ MODKEY|ShiftMask,             XK_comma,      tagmon,         {.i = -1 } },
	{ MODKEY|ShiftMask,             XK_semicolon,  tagmon,         {.i = +1 } },
	{ MODKEY|ShiftMask,             XK_q,          quit,           {0} },
	TAGKEYS(                        XK_ampersand,                     0)
	TAGKEYS(                        XK_eacute,                        1)
	TAGKEYS(                        XK_quotedbl,                      2)
	TAGKEYS(                        XK_apostrophe,                    3)
	TAGKEYS(                        XK_parenleft,                     4)
	TAGKEYS(                        XK_minus,                         5)
	TAGKEYS(                        XK_egrave,                        6)
	TAGKEYS(                        XK_underscore,                    7)
	TAGKEYS(                        XK_ccedilla,                      8)
};

/* button definitions */
/* click can be ClkLtSymbol, ClkStatusText, ClkWinTitle, ClkClientWin, or ClkRootWin */
static Button buttons[] = {
	/* click                event mask      button          function        argument */
	{ ClkLtSymbol,          0,              Button1,        setlayout,      {0} },
	{ ClkLtSymbol,          0,              Button3,        setlayout,      {.v = &layouts[2]} },
	{ ClkWinTitle,          0,              Button2,        zoom,           {0} },
	{ ClkStatusText,        0,              Button2,        spawn,          {.v = termcmd } },
	{ ClkClientWin,         MODKEY,         Button1,        movemouse,      {0} },
	{ ClkClientWin,         MODKEY,         Button2,        togglefloating, {0} },
	{ ClkClientWin,         MODKEY,         Button3,        resizemouse,    {0} },
	{ ClkTagBar,            0,              Button1,        view,           {0} },
	{ ClkTagBar,            0,              Button3,        toggleview,     {0} },
	{ ClkTagBar,            MODKEY,         Button1,        tag,            {0} },
	{ ClkTagBar,            MODKEY,         Button3,        toggletag,      {0} },
};
